'-----------------------------------------------------------------------
'-------------------------  DOMOTICS LIBRARY ---------------------------
'-- OBJECTIVES : Many functions to simplify your Homeseer scripting
'-- LICENSE    : FREE OF CHARGE FOR NON-COMMERCIAL USE
'-----------------------------------------------------------------------

'--------------------------------------------------------------------
'-- OBJECTIVE   : PROCEDURE >> Save a string in a given file
'-- PREREQUISITE: N/A
'-- PARAMS IN   : File		(for example ../tmp/dwn-page.txt)
'--				  String	(for example a downloaded page)
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 24/04/2005
'--------------------------------------------------------------------
Sub SaveFilebyType(aparamFile, aparamPage, aparamFileType)
Dim aobjFile
Dim afileFS

Set aobjFile = CreateObject("Scripting.FileSystemObject")
Set afileFS = aobjFile.OpenTextFile(aparamFile, 2 ,True, aparamFileType)
afileFS.WriteLine(aparamPage)
afileFS.Close
Set afileFS = Nothing
Set aobjFile = Nothing
End sub

Sub SaveFile(astrFile, astrPage) 
SaveFilebyType astrFile, astrPage, G_FILETYPE_UNICODE
End Sub

'--------------------------------------------------------------------
'-- OBJECTIVE   : FUNCTION >> Load a text file and delete it 
'-- PREREQUISITE: N/A
'-- PARAMS IN   : File		(for example ../tmp/dwn-page.txt)
'--				  Boolean	(True if you want to delete the file,
'--							 False if you want to keep the file)
'-- PARAMS OUT  : The loaded file is returned as a string
'-- CREATED BY DOMOTICS
'-- 24/04/2005
'--------------------------------------------------------------------

Function LoadFile(astrFile, aboolToBeDeleted) 
Dim aobjFile
Dim afileFS
Dim i

i=""
Set aobjFile = CreateObject("Scripting.FileSystemObject")
Set afileFS = aobjFile.OpenTextFile(astrFile) 
i = afileFS.ReadAll 
afileFS.Close
If aboolToBeDeleted Then
	If aobjFile.FileExists(astrFile) Then
		aobjFile.DeleteFile astrFile, True 
	End If 
End if
Set afileFS  = Nothing
Set aobjFile = Nothing
LoadFile = i
End Function

'--------------------------------------------------------------------
'-- OBJECTIVE   : FUNCTION >> 2 functions to test the Free,
'--					and used spaces of your disk
'-- PREREQUISITE: N/A
'-- PARAMS IN   : Drive		(for example c)
'-- PARAMS OUT  : Free space or Used Space
'-- CREATED BY DOMOTICS
'-- 15/05/2005
'--------------------------------------------------------------------

Function getFreeSpace(astrDrivePath)
Dim fso, drv, s, Free

Free = -1
'On error resume next 		
Set fso = CreateObject("Scripting.FileSystemObject")
Set drv = fso.GetDrive(fso.GetDriveName(astrDrivePath))

Free = FormatNumber(drv.FreeSpace / 1073741824, 2)
If Err.description <> "" Then
	Free = -1
End if
Set drv = Nothing
Set fso = Nothing
	
getFreeSpace = Free
End Function

Function getUsedSpace(astrDrivePath)
Dim fso, drv, s, Used
Used = -1
'On error resume next		
Set fso = CreateObject("Scripting.FileSystemObject")
Set drv = fso.GetDrive(fso.GetDriveName(astrDrivePath))
	
Used = FormatNumber(drv.TotalSize / 1073741824, 2)
If Err.description <> "" Then
	Used = -1
End if
Set drv = Nothing
Set fso = Nothing
	
getUsedSpace = Used
End Function

'--------------------------------------------------------------------
'-- OBJECTIVE   : FUNCTION >> Does the file exist 
'-- PREREQUISITE: N/A
'-- PARAMS IN   : File with the path 
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 06/08/2005
'--------------------------------------------------------------------

Function isFileExist(astrFile)
Dim astrFullPathToFile
Dim aobjFile
Dim aboolFound

Set aobjFile = CreateObject("Scripting.FileSystemObject")

If instr(astrFile,"..\") > 0 Then
	astrFullPathToFile = hs.GetAppPath & Mid(astrFile, 3, Len(astrFile)-2) 
Else
	astrFullPathToFile = astrFile
End If

If aobjFile.FileExists(astrFullPathToFile) Then
	aboolFound = True
Else
	aboolFound = False
End if

Set aobjFile = Nothing

isFileExist = aboolFound
End Function

'--------------------------------------------------------------------
'-- OBJECTIVE   : FUNCTION >> Does the folder exist 
'-- PREREQUISITE: N/A
'-- PARAMS IN   : Folder with the path 
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 15/10/2005
'--------------------------------------------------------------------

Function isFolderExist(astrFolder)
Dim astrFullPathToFolder
Dim aobjFile
Dim aboolFound

Set aobjFile = CreateObject("Scripting.FileSystemObject")

If instr(astrFolder,"..\") > 0 Then
	astrFullPathToFolder = hs.GetAppPath & Mid(astrFolder, 3, Len(astrFolder)-2) 
Else
	astrFullPathToFolder = astrFolder
End If

If aobjFile.FolderExists(astrFullPathToFolder) Then
	aboolFound = True
Else
	aboolFound = False
End if

Set aobjFile = Nothing

isFolderExist = aboolFound
End Function

'--------------------------------------------------------------------
'-- OBJECTIVE   : PROCEDURE >> Create folder 
'-- PREREQUISITE: N/A
'-- PARAMS IN   : Folder with the path 
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 15/10/2005
'--------------------------------------------------------------------

Sub createFolder(aparamFolder)
Dim afileSys

Set afileSys = CreateObject("Scripting.FileSystemObject")
If Not afileSys.FolderExists(aparamFolder) Then 
	afileSys.CreateFolder(aparamFolder) 
End if

Set afileSys = Nothing
End Sub

'--------------------------------------------------------------------
'-- OBJECTIVE   : FUNCTION >> Extend Filename 
'-- PREREQUISITE: N/A
'-- PARAMS IN   : File or File with partial path
'-- PARAMS OUT  : File with full path from c:
'-- CREATED BY DOMOTICS
'-- 11/04/2006
'--------------------------------------------------------------------
Function extendFileName(aparamFile)
Dim astrFullPathToFolder

If instr(aparamFile,"..\") > 0 Then
	astrFullPathToFolder = hs.GetAppPath & Mid(aparamFile, 3, Len(aparamFile)-2) 
Elseif instr(aparamFile,"c:\") > 0 Then
	astrFullPathToFolder = aparamFile
Elseif instr(aparamFile,"\") = 1 Then
	astrFullPathToFolder = aparamFile
Else
	astrFullPathToFolder = hs.GetAppPath & "\" & aparamFile
End If
extendFileName = astrFullPathToFolder
End Function


'--------------------------------------------------------------------
'-- OBJECTIVE   : Function >> getDateLastModified
'-- PREREQUISITE: N/A
'-- PARAMS IN   : File (full path))
'-- PARAMS OUT  : Date of the last modification
'-- CREATED BY DOMOTICS
'-- 23/07/2006
'--------------------------------------------------------------------
Function getDateLastModified(aparamFile)
Dim aobjFile
Dim afileFS
Dim adateLastModified

Set aobjFile = CreateObject("Scripting.FileSystemObject")
If aobjFile.FileExists(aparamFile) Then
  Set afileFS = aobjFile.GetFile(aparamFile)
  adateLastModified = afileFS.DateLastModified
  Set afileFS = Nothing
Else
  adateLastModified = cdate("01/01/1900")
End if
Set aobjFile = Nothing
getDateLastModified = adateLastModified
End Function

'--------------------------------------------------------------------
'-- OBJECTIVE   : Procedure >> delete a folder
'-- PREREQUISITE: N/A
'-- PARAMS IN   : File (full path))
'-- PARAMS OUT  : Date of the last modification
'-- CREATED BY DOMOTICS
'-- 04/09/2006
'--------------------------------------------------------------------
Sub deleteFolder(aparamFolder)
Dim fileSYS
Dim folderTmp

Set fileSYS = CreateObject("Scripting.FileSystemObject") 
If fileSYS.FolderExists(aparamFolder) Then 
	Set folderTmp = fileSYS.GetFolder(aparamFolder) 
	folderTmp.Delete 
	Set folderTmp = Nothing
End if
Set fileSYS = Nothing
End sub