'-----------------------------------------------------------------------
'-------------------------  DOMOTICS LIBRARY ---------------------------
'-- OBJECTIVES : Many functions to simplify your Homeseer scripting
'-- LICENSE    : FREE OF CHARGE FOR NON-COMMERCIAL USE
'-----------------------------------------------------------------------

'-----------------------------------------------------------------------
'-- OBJECTIVE   : FUNCTION >> Convert String Status to X10 Status
'-- PREREQUISITE: N/A
'-- PARAMS IN   : X10 String Status 
'-- PARAMS OUT  : X10 Status (integer)
'-- CREATED BY DOMOTICS
'-- 01/11/2003
'-----------------------------------------------------------------------
Function Str2X10Status(astrStatus)
Dim astrNewStatus

if UCase(astrStatus) = UCase("All Units Off") then	
	astrNewStatus=0
elseif UCase(astrStatus) = UCase("All Lights On") then	
	astrNewStatus=1
elseif UCase(astrStatus) = UCase("ON") then	
	astrNewStatus=2
elseif UCase(astrStatus) = UCase("OFF") then	
	astrNewStatus=3
elseif UCase(astrStatus) = UCase("Dim") then	
	astrNewStatus=4
elseif UCase(astrStatus) = UCase("Bright") then	
	astrNewStatus=5
elseif UCase(astrStatus) = UCase("All Lights Off") then	
	astrNewStatus=6
elseif UCase(astrStatus) = UCase("Extended") then	
	astrNewStatus=7
elseif UCase(astrStatus) = UCase("Hail Request" )	then	
	astrNewStatus=8
elseif UCase(astrStatus) = UCase("Hail Ack")	then	
	astrNewStatus=9
elseif UCase(astrStatus) = UCase("Preset Dim" )	then	
	astrNewStatus=10
elseif UCase(astrStatus) = UCase("Ex Data Xfer") then	
	astrNewStatus=11
elseif UCase(astrStatus) = UCase("Status On") then	
	astrNewStatus=12
elseif UCase(astrStatus) = UCase("Status Off") then	
	astrNewStatus=13
elseif UCase(astrStatus) = UCase("Status Request")	then	
	astrNewStatus=14
elseif UCase(astrStatus) = UCase("Dim to Off" )	then	
	astrNewStatus=15
elseif UCase(astrStatus) = UCase("Unknown")	then	
		astrNewStatus=17
elseif UCase(astrStatus) = UCase(G_STR_DIM_FROM_BOTTOM) then	
		astrNewStatus=41
elseif UCase(astrStatus) = UCase(G_STR_DIM_FROM_TOP) then	
		astrNewStatus=42
elseif UCase(astrStatus) = UCase(G_STR_BRIGHT_FROM_BOTTOM) then	
		astrNewStatus=51
elseif UCase(astrStatus) = UCase(G_STR_BRIGHT_FROM_TOP) then	
		astrNewStatus=52
else	astrNewStatus=17
end if
Str2X10Status=astrNewStatus
End Function


'----------------------------------------------------------------------
'-- OBJECTIVE   : FUNCTION >> Convert X10 Status to X10 String Status
'-- PREREQUISITE: N/A
'-- PARAMS IN   : X10 Status (integer)
'-- PARAMS OUT  : X10 String Status
'-- CREATED BY DOMOTICS
'-- 19/11/2002
'----------------------------------------------------------------------

Function X10Status2Str(astrStatus)
Select Case astrStatus
Case 0
     X10Status2Str="All Units Off"
Case 1
     X10Status2Str="All Lights On"
Case 2
     X10Status2Str="ON"
Case 3
     X10Status2Str="OFF"
Case 4
     X10Status2Str="Dim"
Case 5
     X10Status2Str="Bright"
Case 6
     X10Status2Str="All Lights Off"
Case 7
     X10Status2Str="Extended"
Case 8
     X10Status2Str="Hail Request"
Case 9
     X10Status2Str="Hail Ack"
Case 10
     X10Status2Str="Preset Dim"
Case 11
     X10Status2Str="Ex Data Xfer"
Case 12
     X10Status2Str="Status On"
Case 13
     X10Status2Str="Status Off"
Case 14
     X10Status2Str="Status Request"
Case 15
     X10Status2Str="Dim to Off"
Case 17
     X10Status2Str="Unknown"
Case 41
     X10Status2Str=G_STR_DIM_FROM_BOTTOM
Case 42
     X10Status2Str=G_STR_DIM_FROM_TOP
Case 51
     X10Status2Str=G_STR_BRIGHT_FROM_BOTTOM
Case 52
     X10Status2Str=G_STR_BRIGHT_FROM_TOP
Case else
	 X10Status2Str=astrStatus
End Select
End Function


'-----------------------------------------------------------------------
'-- OBJECTIVE   : PROCEDURE >> Check and Create Homeseer Device,
'--							  If it doesn't exist.
'-- PREREQUISITE: N/A
'-- PARAMS IN   : Device 	(for example A1)
'--			 	  Label 		(for example Store)
'--				  Location 	(for example Bureau)
'--				  Type		(for example Virtual)
'--				  Status		(for example ON)
'--				  Mode		(for example G_DATABASE or not)
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 01/11/2003
'-----------------------------------------------------------------------

Sub CheckAndCreateDevice(astrFile, astrMode)
Dim astrCAN_DIM
Dim astrHC
Dim astrDC
Dim astrLOCATION
Dim astrDEV_TYPE_STRING
Dim astrNAME
Dim astrREF
Dim astrSTATUS_SUPPORT
Dim astrMISC
Dim astrVALUES
Dim astrBUTTONS
Dim astrGRAPHICS
Dim astrDevice
Dim astrDEFAULT_STATUS
Dim astrDEFAULT_VALUE
Dim astrDEFAULT_STRING
Dim aboolDevNotExist
Dim aboolNoValueInDB
Dim aobjFile
Dim astrFullPathToFile

Set aobjFile = CreateObject("Scripting.FileSystemObject")

If instr(astrFile,"..\") > 0 Then
	astrFullPathToFile = hs.GetAppPath & Mid(astrFile, 3, Len(astrFile)-2) 
Else
	astrFullPathToFile = astrFile
End If

If aobjFile.FileExists(astrFullPathToFile) Then
	astrCAN_DIM			= hs.GetINISetting("DEVICE", "CAN_DIM", "true", astrFile)
	astrHC				= hs.GetINISetting("DEVICE", "HC", "", astrFile)
	astrDC				= hs.GetINISetting("DEVICE", "DC", "", astrFile)
	astrLOCATION		= hs.GetINISetting("DEVICE", "LOCATION", "", astrFile)
	astrDEV_TYPE_STRING	= hs.GetINISetting("DEVICE", "DEV_TYPE_STRING", "", astrFile)
	astrNAME			= hs.GetINISetting("DEVICE", "NAME", "", astrFile)
	astrREF				= hs.GetINISetting("DEVICE", "REF", "", astrFile)
	astrSTATUS_SUPPORT	= hs.GetINISetting("DEVICE", "STATUS_SUPPORT", "false", astrFile)
	astrMISC			= hs.GetINISetting("DEVICE", "MISC", "", astrFile)
	astrVALUES			= hs.GetINISetting("DEVICE", "VALUES", "", astrFile)
	astrBUTTONS			= hs.GetINISetting("DEVICE", "BUTTONS", "", astrFile)
	astrGRAPHICS		= hs.GetINISetting("DEVICE", "GRAPHICS", "", astrFile)
	astrDEFAULT_STATUS	= hs.GetINISetting("DEVICE", "DEFAULT_STATUS", "", astrFile)
	astrDEFAULT_STRING	= hs.GetINISetting("DEVICE", "DEFAULT_STRING", "", astrFile)
	astrDEFAULT_VALUE	= hs.GetINISetting("DEVICE", "DEFAULT_VALUE", "", astrFile)
	
	astrDevice			= trim(cstr(astrHC)) & trim(cstr(astrDC))

	If (hs.DeviceExists(astrDevice)=-1) Then   '-- It doesn't exist
		aboolDevNotExist = True
	Else
		If G_RECREATE_MODE Then
			WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, """" & astrDevice &""" is deleted", G_DEFAULT_LOG_FILE
			hs.DeleteDevice(hs.GetDeviceRef(astrDevice))	
			aboolDevNotExist = True
		Else
			aboolDevNotExist = False	
		End if
		
	End if

	If aboolDevNotExist Then
		Dim aDevice
'		Set aDevice 			= hs.getdevice(hs.NewDevice(astrNAME))
		Set aDevice 			= hs.NewDeviceEx(astrNAME)
		aDevice.location		= astrLOCATION
		aDevice.dev_type_string = astrDEV_TYPE_STRING	
		aDevice.hc 				= astrHC
		aDevice.dc 				= astrDC
		If Left(hs.version,1) = "2" Then	'---- Si Homeseer v2.x ----
			'-- can_dim est bugg sur certains HS2
		Else '---- Si Homeseer v2.x ----
			aDevice.can_dim   		= astrCAN_DIM
		End if
		aDevice.name 			= astrNAME
		hs.SaveEventsDevices
		Set aDevice 			= Nothing
	End if

	If (astrMode = G_DATABASE) Then			'-- Default value is applied
		If LoadDeviceFromDb(astrDevice) Then
			aboolNoValueInDB = False
		Else
			aboolNoValueInDB = True
		End if
	Else 
		aboolNoValueInDB = True
	End if

	If aboolNoValueInDB Then
		SetDevice astrDevice, astrDEFAULT_STRING, astrDEFAULT_STATUS, astrDEFAULT_VALUE
	End If
	
Else
	WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, """" & astrFullPathToFile &""" not found", G_DEFAULT_LOG_FILE	
End if
Set aobjFile = Nothing
End Sub

'-----------------------------------------------------------------------
'-- OBJECTIVE   : PROCEDURE >> Check and Create Homeseer event,
'--							  If it doesn't exist.
'-- PREREQUISITE: N/A
'-- PARAMS IN   : TBD
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 01/11/2003
'-----------------------------------------------------------------------

Sub CheckAndCreateEvent(astrFile, astrMode)
Dim astrNAME
Dim astrEVT_TIME
Dim astrVOICE_CMD
Dim astrEVT_ABS_TIME
Dim astrPHONE_ACTIONS
Dim astrEVT_APP_PATH
Dim astrEVT_DATE
Dim astrEVT_DAYS
Dim astrEVT_FCT
Dim astrEVT_HC
Dim astrEVT_MAIL_MESSAGE
Dim astrEVT_MAIL_SUBJ
Dim astrEVT_OFFSET
Dim astrEVT_OFFSET_BEFORE
Dim astrRETRIGGER_DELAY
Dim astrEVT_TRIG_HC
Dim astrEVT_TRIG_DC
Dim astrEVT_TRIG_FUNC
Dim astrEVT_WAV_PATH
Dim astrEVENTS
Dim astrIR
Dim astrMAIL_ATTACH_PATH
Dim astrMISC
Dim astrMISC2
Dim astrPOPFROM
Dim astrREC_MINS
Dim astrREC_SECS
Dim astrSCRIPTS
Dim astrSPEECH
Dim astrSECURITY_OFFSET
Dim astrEVT_CONDITIONS
Dim astrTIME
Dim astrEVT_DEVICES
Dim astrGROUP
Dim aboolEvtNotExit
Dim aobjFile
Dim astrFullPathToFile
Dim astrResult
Dim adevTemp

Set aobjFile = CreateObject("Scripting.FileSystemObject")

If instr(astrFile,"..\") > 0 Then
	astrFullPathToFile = hs.GetAppPath & Mid(astrFile, 3, Len(astrFile)-2) 
Else
	astrFullPathToFile = astrFile
End If

If aobjFile.FileExists(astrFullPathToFile) Then
	astrNAME				= hs.GetINISetting("EVENT", "NAME", "", astrFile)
	astrEVT_TIME			= hs.GetINISetting("EVENT", "EVT_TIME", "", astrFile)
	astrVOICE_CMD			= hs.GetINISetting("EVENT", "VOICE_CMD", "", astrFile)
	astrEVT_ABS_TIME		= hs.GetINISetting("EVENT", "EVT_ABS_TIME", 7, astrFile)
	astrPHONE_ACTIONS		= hs.GetINISetting("EVENT", "PHONE_ACTIONS", "", astrFile)
	astrEVT_APP_PATH		= hs.GetINISetting("EVENT", "EVT_APP_PATH", "", astrFile)
	astrEVT_DATE			= hs.GetINISetting("EVENT", "EVT_DATE", "", astrFile)
	astrEVT_DAYS			= hs.GetINISetting("EVENT", "EVT_DAYS", "", astrFile)
	astrEVT_FCT				= hs.GetINISetting("EVENT", "EVT_FCT", "", astrFile)
	astrEVT_HC				= hs.GetINISetting("EVENT", "EVT_HC", "", astrFile)
	astrEVT_MAIL_MESSAGE	= hs.GetINISetting("EVENT", "EVT_MAIL_MESSAGE", "", astrFile)
	astrEVT_MAIL_SUBJ		= hs.GetINISetting("EVENT", "EVT_MAIL_SUBJ", "", astrFile)
	astrEVT_OFFSET			= hs.GetINISetting("EVENT", "EVT_OFFSET", "", astrFile)
	astrEVT_OFFSET_BEFORE	= hs.GetINISetting("EVENT", "EVT_OFFSET_BEFORE", "", astrFile)
	astrRETRIGGER_DELAY		= hs.GetINISetting("EVENT", "RETRIGGER_DELAY", "", astrFile)
	astrEVT_TRIG_HC			= hs.GetINISetting("EVENT", "EVT_TRIG_HC", "", astrFile)
	astrEVT_TRIG_DC			= hs.GetINISetting("EVENT", "EVT_TRIG_DC", "", astrFile)
	astrEVT_TRIG_FUNC		= hs.GetINISetting("EVENT", "EVT_TRIG_FUNC", "", astrFile)
	astrEVT_WAV_PATH		= hs.GetINISetting("EVENT", "EVT_WAV_PATH", "", astrFile)
	astrEVENTS				= hs.GetINISetting("EVENT", "EVENTS", "", astrFile)
	astrIR					= hs.GetINISetting("EVENT", "IR", "", astrFile)
	astrMAIL_ATTACH_PATH	= hs.GetINISetting("EVENT", "MAIL_ATTACH_PATH", "", astrFile)
	astrMISC				= hs.GetINISetting("EVENT", "MISC", 0, astrFile)
	astrMISC2				= hs.GetINISetting("EVENT", "MISC2", 0, astrFile)
	astrPOPFROM				= hs.GetINISetting("EVENT", "POPFROM", "", astrFile)
	astrREC_MINS			= hs.GetINISetting("EVENT", "REC_MINS", 0, astrFile)
	astrREC_SECS			= hs.GetINISetting("EVENT", "REC_SECS", 0, astrFile)
	astrSCRIPTS				= hs.GetINISetting("EVENT", "SCRIPTS", "", astrFile)
	astrSPEECH				= hs.GetINISetting("EVENT", "SPEECH", "", astrFile)
	astrSECURITY_OFFSET		= hs.GetINISetting("EVENT", "SECURITY_OFFSET", "", astrFile)
	astrEVT_CONDITIONS		= hs.GetINISetting("EVENT", "EVT_CONDITIONS", "", astrFile)
	astrTIME				= hs.GetINISetting("EVENT", "TIME", "", astrFile)
	astrEVT_DEVICES			= hs.GetINISetting("EVENT", "EVT_DEVICES", "", astrFile)
	astrGROUP				= hs.GetINISetting("EVENT", "GROUP", "", astrFile)
'msgbox astrGROUP
	If (hs.EventExists(astrName)) Then
		aboolEvtNotExit  = false
		If G_RECREATE_MODE Then
			WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, """" & astrNAME &""" is deleted", G_DEFAULT_LOG_FILE
			hs.DeleteEvent(astrName)
			aboolEvtNotExit  = True
		End if
	Else
		aboolEvtNotExit  = True	
	End if

	If aboolEvtNotExit Then
			Dim aobjEv
			Dim astrIndex
			Dim aobjCDT

			Set aobjEv  = hs.NewEventEx(astrName)
			aobjEv.ev_abs_time = Cint(astrEVT_ABS_TIME)
			aobjEv.ev_time	= astrEVT_TIME
			
			aobjEv.rec_mins		= Cint(astrREC_MINS)
			aobjEv.rec_secs		= Cint(astrREC_SECS)
			
			If astrEVT_TRIG_HC <> "" Then
				If astrEVT_ABS_TIME = 11 Then
				'recherche la rfrence du device qui a pour Code EVT_TRIG_HC   & EVT_TRIG_DC
				Dim RefDuDevice
				Dim CodeDuDevice
				CodeDuDevice = astrEVT_TRIG_HC & astrEVT_TRIG_DC
				RefDuDevice = hs.GetDeviceRef(CodeDuDevice)
				'crit la rfrence trouve dans EVT_TRIG_HC
				aobjEv.ev_trig_hc	= RefDuDevice
				'Il faut ensuite que EVT_TRIG_DC contienne ce qu'on met habituellement dans EVT_TRIG_FUNC
				astrEVT_TRIG_DC = astrEVT_TRIG_FUNC
				astrEVT_TRIG_FUNC = ""
				else:
				aobjEv.ev_trig_hc	= astrEVT_TRIG_HC
				end if
			End if
			
			If astrEVT_TRIG_DC <> "" Then
				aobjEv.ev_trig_dc	= astrEVT_TRIG_DC
			End if
			
			If astrEVT_TRIG_FUNC <> "" Then
				aobjEv.ev_trig_func = astrEVT_TRIG_FUNC
			End if
			
			If astrMISC <> 0 Then
				aobjEv.misc			= astrMISC
			End if
			
			If astrMISC2 <> 0 Then
				aobjEv.misc2		= astrMISC2
			End if			

			If astrEVENTS <> "" Then
				If Left(hs.version,1) = "2" Then
				    astrResult = hs.AddAction(hs.geteventRefByName(astrName),2,astrEVENTS) 
				Else
					aobjEv.events		= astrEVENTS
				End If
			End if
									
			'Set aobjCDT = hs.NewCondition
			'aobjCDT.cdtype = Cint(astrTypeOfCdt)
			'aobjCDT.condition = Cint(astrCDT)
			'aobjCDT.time=astrTIME
			'aobjEv.ev_conditions.add aobjCDT
			
			If astrSCRIPTS <> "" Then
				If Left(hs.version,1) = "2" Then
				    astrResult = hs.AddAction(hs.geteventRefByName(astrName),5,astrSCRIPTS) 
				Else
					aobjEv.scripts=astrSCRIPTS
				End If
			End If
			
			If astrSPEECH <> "" Then
				aobjEv.speech=astrSPEECH
			End if
			
			If astrGROUP <> "" Then
				aobjEv.group=astrGROUP	
			End if
						
			If astrEVT_DEVICES <> "" Then
				Dim astrBuffer
				Dim astrEvtDevices
				Dim i
				Dim Dev
				
				astrBuffer = Split(astrEVT_DEVICES, G_SEP)
				i=0
				While i <= UBound(astrBuffer)
					astrEvtDevices = Split(astrBuffer(i), G_COMMA)
					If Ubound(astrEvtDevices) = 3 Then
						If Left(hs.version,1) = "2" Then	'---- Si Homeseer v2.x ----
							WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Linked devices for HS2 :" & astrEvtDevices(0) & astrEvtDevices(1) & astrEvtDevices(2) & astrEvtDevices(3), G_DEFAULT_LOG_FILE
							adevTemp	=	hs.GetDeviceRef(astrEvtDevices(0) & astrEvtDevices(1))
							If CInt(astrEvtDevices(3)) <> 0 Then
								astrResult 	= 	hs.AddAction(hs.geteventRefByName(astrName),11,0,CInt(astrEvtDevices(3)),0) 
								WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Linked devices for HS2, delay error :" & astrResult, G_DEFAULT_LOG_FILE
							End If
							astrResult 	= 	hs.AddAction(hs.geteventRefByName(astrName),1,adevTemp,Str2X10Status(astrEvtDevices(2))) 
							WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Linked devices for HS2, device error :" & astrResult, G_DEFAULT_LOG_FILE
							WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Linked devices for HS2 created", G_DEFAULT_LOG_FILE
							
						Else								'---- Si Homeseer v1.x ----
							WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Linked devices for HS1 :" & astrEvtDevices(0) & astrEvtDevices(1) & astrEvtDevices(2) & astrEvtDevices(3), G_DEFAULT_LOG_FILE
							Set Dev  		= hs.NewDevFunc
							Dev.devid		= hs.GetDeviceRef(astrEvtDevices(0) & astrEvtDevices(1))
							Dev.func 		= Str2X10Status(astrEvtDevices(2))
							Dev.secs_delay 	= astrEvtDevices(3)
							aobjEv.ev_devices.add Dev
							Set Dev 		= Nothing
							WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Linked devices for HS1 created", G_DEFAULT_LOG_FILE
						End If
					Else
						WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_CRI, """" & astrBuffer(i) &""" has a problem of parameters", G_DEFAULT_LOG_FILE
						'-- Unknown use case
					End if
					i = i+1
				Wend
			End If
			 
			hs.SaveEventsDevices
			Set aobjEv = Nothing
	End if
Else
	WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, """" & astrFullPathToFile &""" not found", G_DEFAULT_LOG_FILE	
End if
Set aobjFile = Nothing
End Sub

'-----------------------------------------------------------------------
'-- OBJECTIVE   : PROCEDURE >> Write a log according the level
'-- PREREQUISITE: N/A
'-- PARAMS IN   : Name		(for example MANAGE.SHUTTERS)
'--				  Script		(for example manage.shutters.vbs)
'--				  Level		(for example SEVERE or CRITICAL)
'--				  Message	(for example "All shutters are off")
'--				  LogFile  	(for example path + logfile)
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 01/11/2003
'-----------------------------------------------------------------------

Sub WriteLog(astrName, astrScript, astrLevel, astrMessage, astrLogFile)
Dim aboolWrite
Dim afileFS, aobjFile
Dim i

aboolWrite=False
If (hs.GetVar(astrName & "_LEVEL") = G_TIV_INF)                              Then aboolWrite=True
If (hs.GetVar(astrName & "_LEVEL") = G_TIV_WAR) and (astrLevel <> G_TIV_INF) Then aboolWrite=True
If (hs.GetVar(astrName & "_LEVEL") = G_TIV_CRI) and (astrLevel = G_TIV_CRI _
									or    astrLevel = G_TIV_SEV ) 			 Then aboolWrite=True
If (hs.GetVar(astrName & "_LEVEL") = G_TIV_SEV) and (astrLevel = G_TIV_SEV ) Then aboolWrite=True	
If G_DEBUG_MODE Then aboolWrite = True

If aboolWrite Then
'   Log dans Homeseer
	hs.WriteLog astrLevel, astrName & ", " & astrScript & ", " & now() & ", " & astrMessage 

	If hs.GetVar(astrName & "_MODE") = G_DATABASE  Then
		insertLog astrLevel, astrName, astrScript, now(), astrMessage
	Else
'		Log dans un fichier
		If astrLogFile <> "" Then
			Set aobjFile = CreateObject("Scripting.FileSystemObject")
			Set afileFS = aobjFile.OpenTextFile(astrLogFile, 8,True ,0)
			afileFS.WriteLine(astrLevel & ", " & astrName & ", " & astrScript & ", " & now() & ", " & astrMessage)
			afileFS.Close
			Set afileFS = Nothing
			Set aobjFile = Nothing
		End if
	End if
End if

End sub

'-----------------------------------------------------------------------
'-- OBJECTIVE   : PROCEDURE >> Load or Create Homeseer Variable
'-- PREREQUISITE: N/A
'-- PARAMS IN   : Key		(for example MANAGE.SHUTTERS)
'--				  Value		(for example ../log/manage.shutters.log)
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 01/11/2003
'-----------------------------------------------------------------------

Sub SetVar(astrValue, astrDefaultValue)
Dim astrError

astrError = hs.GetVar(astrValue)
If astrError = G_NAME_NOTFOUND Then
	hs.CreateVar(astrValue)
	astrError = hs.SaveVar(astrValue, astrDefaultValue)
Else
	hs.SaveVar astrValue, astrDefaultValue
End if
End sub

'-----------------------------------------------------------------------
'-- OBJECTIVE   : PROCEDURE >> Load properties.ini for a given module
'-- PREREQUISITE: N/A
'-- PARAMS IN   : Application		(for example READ.1-WIRE)
'--				  File				(for example ../config/properties.ini)
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 01/11/2003 
'-----------------------------------------------------------------------
Sub LoadPropertyFile(astrAppli,astrFile)
Dim astrMode
Dim astrNbDv
Dim astrNbEv
Dim i
Dim atabDv
Dim atabEv
Dim astrLevel
Dim astrDevices
Dim astrEvents
Dim astrBuffer
Dim astrConfig

astrMode	= hs.GetINISetting("COMMON","MODE",G_ALONE,astrFile)
astrLevel	= hs.GetINISetting("COMMON","LEVEL",G_TIV_SEV,astrFile)
astrConfig  = hs.GetINISetting("COMMON","CONFIG","..\scripts\config\",astrFile)
astrDevices = hs.GetINISetting("COMMON","DEVICES","",astrFile)
astrEvents  = hs.GetINISetting("COMMON","EVENTS","",astrFile)

SetVar astrAppli & "_LEVEL", astrLevel
SetVar astrAppli & "_MODE",  astrMode

atabDv	 	= Split(astrDevices, G_SEP)
atabEv	 	= Split(astrEvents,  G_SEP)

astrNbDv 	= UBound(atabDv) 
astrNbEv 	= UBound(atabEv) 

i=0
While (i <= Cint(astrNbDv))
	CheckAndCreateDevice astrConfig & atabDv(i), astrMode
	i=i+1
Wend

i=0
While (i <= Cint(astrNbEv))
	CheckAndCreateEvent astrConfig & atabEv(i), astrMode
	i=i+1
Wend
End Sub

'--------------------------------------------------------------------
'-- OBJECTIVE   : PROCEDURE >> Set the value for a given device
'-- PREREQUISITE: N/A
'-- PARAMS IN   : Device		(for example A1)
'--				  Type			(for example 2 for ON/OFF device)
'--				  Command		(for example "On" to be sent)
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 20/11/02
'--------------------------------------------------------------------

Sub SetDevice(astrDevice, astrDEFAULT_STRING, astrDEFAULT_STATUS, astrDEFAULT_VALUE)
Dim astrStatus	
Dim astrString
Dim astrValue
Dim astrNewOrdre
Dim aboolSet
Dim aintDimValue

astrValue	=	hs.DeviceValue(astrDevice)
astrStatus =	hs.DeviceStatus(astrDevice)
astrString = hs.DeviceString(astrDevice)

'-- IF STATUS IS AN INTEGER, WE CONVERT IT TO A STRING : DIM, DIMFB, ON, etc -------------------------------------------
If isNumeric(astrDEFAULT_STATUS) Then
	   astrDEFAULT_STATUS = X10Status2Str(astrDEFAULT_STATUS)
End if
WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "SetDevice " & astrDevice & " with " & _
astrDEFAULT_STRING & "/" & astrDEFAULT_STATUS & "/" & astrDEFAULT_VALUE, G_DEFAULT_LOG_FILE	

'-- SETTING THE STRING -------------------------------------------------------------------------------------------------
aboolSet	=	False
If (astrDEFAULT_STRING <> "") Then
    If ((astrString <> astrDEFAULT_STRING) or (G_SENDONLY_NEWX10 = False))  Then
  		hs.SetDeviceString astrDevice, astrDEFAULT_STRING, True
  		hs.SetDeviceLastChange astrDevice, now
  		aboolSet = True
  		'-- RESET VALUE WHEN STRING = ??? (G_DEFAULT_VALUE) --------------------------------------------------------------
  		If astrDEFAULT_STRING = G_DEFAULT_VALUE Then
  		    hs.SetDeviceValue astrDevice, 0
  		    hs.SetDeviceLastChange astrDevice, now
  		End if
  	End if
End if

'-- SETTING VALUE (ONLY WHEN STATUS IS NOT DIM USE CASE) ---------------------------------------------------------------
If (astrDEFAULT_VALUE <> "") and (astrDEFAULT_STATUS = "")  Then
    If (astrValue <> astrDEFAULT_VALUE) or (G_SENDONLY_NEWX10 = False) Then
  		hs.SetDeviceValue astrDevice, astrDEFAULT_VALUE
  		hs.SetDeviceLastChange astrDevice, now	
  		aboolSet = True
  	End if
End if

'-- SETTING STATUS -----------------------------------------------------------------------------------------------------		
If  (astrDEFAULT_STATUS <> "") Then	
  If (Str2X10Status(astrDEFAULT_STATUS) = G_STATUS_ON  ) or (Str2X10Status(astrDEFAULT_STATUS) = G_STATUS_OFF)  Then
    If (Str2X10Status(astrDEFAULT_STATUS) <> astrStatus) or (G_SENDONLY_NEWX10 = False)  Then
      		hs.SetDeviceLastChange astrDevice, now		
      		aboolSet = True	
      		If  (hs.execx10(astrDevice, astrDEFAULT_STATUS, 0, 0) = 0)  Then
      		    WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Error sending """ & astrDEFAULT_STATUS & _
              """ to " & astrDevice, G_DEFAULT_LOG_FILE
          End if
    End if
  
  ElseIf (Str2X10Status(astrDEFAULT_STATUS) = G_STATUS_DIM ) or _
         (Str2X10Status(astrDEFAULT_STATUS) = G_STATUS_BRIGHT)  Then
    		  hs.SetDeviceLastChange astrDevice, now		
    		  aboolSet = True	
    		  If (hs.execx10(astrDevice, astrDEFAULT_STATUS, astrDEFAULT_VALUE, 0) = 0)  Then
    		      WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Error sending """ & astrDEFAULT_STATUS & _
              "/"  & astrValue & """ to " & astrDevice, G_DEFAULT_LOG_FILE
          End if
        
  ElseIf (Str2X10Status(astrDEFAULT_STATUS) = G_STATUS_DIM_FROM_BOTTOM ) or _
         (Str2X10Status(astrDEFAULT_STATUS) = G_STATUS_BRIGHT_FROM_BOTTOM)  Then
         If (astrValue <> astrDEFAULT_VALUE) or (G_SENDONLY_NEWX10 = False)  Then
      		  If (hs.execx10(astrDevice, X10Status2Str(G_STATUS_OFF), 0, 0) = 0)  Then
  		          WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Error sending """ & astrDEFAULT_STATUS & _
                "/0"" to " & astrDevice, G_DEFAULT_LOG_FILE
            Else
          		  If (hs.execx10(astrDevice, X10Status2Str(G_STATUS_BRIGHT), astrDEFAULT_VALUE, 0) = 0) Then
          		      WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Error sending """ & _
                    astrDEFAULT_STATUS & "/"  & astrValue & """ to " & astrDevice, G_DEFAULT_LOG_FILE
                End if            
            End if            
         		hs.SetDeviceLastChange astrDevice, now	
			      aboolSet = True
          End if
          
  ElseIf (Str2X10Status(astrDEFAULT_STATUS) = G_STATUS_DIM_FROM_TOP) or _
         (Str2X10Status(astrDEFAULT_STATUS) = G_STATUS_BRIGHT_FROM_TOP) Then
         If (astrValue <> astrDEFAULT_VALUE) or (G_SENDONLY_NEWX10 = False) Then
      		  If (hs.execx10(astrDevice, X10Status2Str(G_STATUS_ON), 100, 0) = 0) Then
  		          WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Error sending """ & astrDEFAULT_STATUS & _
                "/100"" to " & astrDevice, G_DEFAULT_LOG_FILE
            Else
          		  If (hs.execx10(astrDevice, X10Status2Str(G_STATUS_DIM), astrDEFAULT_VALUE, 0) = 0) Then
          		      WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Error sending """ & _
                    astrDEFAULT_STATUS & "/"  & astrValue & """ to " & astrDevice, G_DEFAULT_LOG_FILE
                End if            
            End if            
         		hs.SetDeviceLastChange astrDevice, now	
			      aboolSet = True
          End if    
                     
  ElseIf (Str2X10Status(astrDEFAULT_STATUS) = G_STATUS_EXTENDED)  Then
         If (astrValue <> astrDEFAULT_VALUE) or (G_SENDONLY_NEWX10 = False) Then
      		  If (hs.execx10(astrDevice, X10Status2Str(G_STATUS_EXTENDED), astrDEFAULT_VALUE, 3) = 0) Then
  		          WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Error sending """ & astrDEFAULT_STATUS & _
                "/" & astrDEFAULT_VALUE & """ to " & astrDevice, G_DEFAULT_LOG_FILE
            End if            
         		hs.SetDeviceLastChange astrDevice, now	           
         		hs.SetDeviceStatus astrDevice, G_STATUS_ON
			      aboolSet = True
          End if         
          
  Else
          hs.SetDeviceValue astrDevice, astrDEFAULT_VALUE
         	hs.SetDeviceLastChange astrDevice, now	
			    aboolSet = False            
  End if
End if

'-- SAVING STRING / STATUS / VALUE WHEN SOMETHING HAS CHANGED ----------------------------------------------------------
If aboolSet Then
	   WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Saving " & astrDevice & " changes in db (" & _
     astrDEFAULT_STRING & "/" & astrDEFAULT_STATUS & "/" & astrDEFAULT_VALUE & ")", G_DEFAULT_LOG_FILE
     
	   SaveDeviceChange astrDevice	
End If
End Sub

'-- SetDevice, deprecated one
Sub SetDeviceOld1(astrDevice, astrDEFAULT_STRING, astrDEFAULT_STATUS, astrDEFAULT_VALUE)
Dim astrStatus	
Dim astrString
Dim astrValue
Dim astrNewOrdre
Dim aboolSet

astrValue	=	hs.DeviceValue(astrDevice)
astrStatus	=	hs.DeviceStatus(astrDevice)
astrString	= 	hs.DeviceString(astrDevice)

WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "String " & astrDEFAULT_STATUS  & " is received as input", G_DEFAULT_LOG_FILE	
If isNumeric(astrDEFAULT_STATUS) Then
	astrDEFAULT_STATUS = X10Status2Str(astrDEFAULT_STATUS)
End if
WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "String converted to " & astrDEFAULT_STATUS, G_DEFAULT_LOG_FILE	
'
aboolSet	=	False
If (astrDEFAULT_STRING <> "") Then
	If astrString <> astrDEFAULT_STRING Then
		hs.SetDeviceString astrDevice, astrDEFAULT_STRING, True
		hs.SetDeviceLastChange astrDevice, now
		aboolSet = True
		WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "String """ & astrDEFAULT_STRING  & """ is assigned", G_DEFAULT_LOG_FILE	
	Else
		WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "astrDEFAULT_STRING is equal to current string : " & astrString, G_DEFAULT_LOG_FILE	
	End if
Else
	WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "astrDEFAULT_STRING is empty !", G_DEFAULT_LOG_FILE	
End if

If (astrDEFAULT_VALUE <> "") Then
	If astrValue <> astrDEFAULT_VALUE Then
		hs.SetDeviceValue astrDevice, astrDEFAULT_VALUE
		hs.SetDeviceLastChange astrDevice, now	
		aboolSet = True
		WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Value """ & astrDEFAULT_VALUE  & """ is assigned", G_DEFAULT_LOG_FILE
	Else
		WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "astrDEFAULT_VALUE is equal to current Value : " & astrValue, G_DEFAULT_LOG_FILE
	End if
Else
	WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "astrDEFAULT_VALUE is empty !", G_DEFAULT_LOG_FILE
End if
If (astrDEFAULT_STATUS <> "") Then	
	If G_SENDONLY_NEWX10 Then
		If (astrStatus <> Str2X10Status(astrDEFAULT_STATUS)) Then
			hs.SetDeviceLastChange astrDevice, now		
			aboolSet = True			
			WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, _
				"Status """ & astrDEFAULT_STATUS & """ is sent. X10 return code=" &  hs.execx10(astrDevice, trim(astrDEFAULT_STATUS),0,0), _
				G_DEFAULT_LOG_FILE		
		Else
			aboolSet = False		
			hs.SetDeviceStatus astrDevice, Str2X10Status(astrDEFAULT_STATUS)
			WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, _
					"Status """ & astrDEFAULT_STATUS & """ isn't sent because this status is already set", _
					G_DEFAULT_LOG_FILE		
		End if
	Else
		hs.SetDeviceLastChange astrDevice, now		
		aboolSet = True	
		WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, _
				"Status """ & astrDEFAULT_STATUS & """ is sent. X10 return code=" &  hs.execx10(astrDevice, trim(astrDEFAULT_STATUS),0,0), _
				G_DEFAULT_LOG_FILE		

	End if
Else
	WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "astrDEFAULT_STATUS is empty !", G_DEFAULT_LOG_FILE	
End if
If aboolSet Then
	WriteLog G_DEFAULT_FOLDER_NAME, G_DEFAULT_SCRIPT, G_TIV_INF, "Saving " & astrDevice & " changes", G_DEFAULT_LOG_FILE
	SaveDeviceChange astrDevice	
End if
End Sub

'--------------------------------------------------------------------
'-- OBJECTIVE   : FUNCTION >> Check If all devices of a properties.ini
'--							  have a given status (unknown for example)
'-- PREREQUISITE: N/A
'-- PARAMS IN   : Application Name	(for example REBOOT)
'--				  File				(for example ../config/properties.ini)
'--				  Status			(for example 17 = Unknown)
'-- PARAMS OUT  : True if all devices have the expexted value
'--				  False if one device hasn't this expected value
'-- CREATED BY DOMOTICS
'-- 24/04/2005
'--------------------------------------------------------------------

Function CheckDevices(astrName, astrFile, astrStatus) 
Dim i
Dim aboolAllDevAreKnown
Dim astrConfig
Dim astrBuffer
Dim atabDv
Dim astrNbDv
Dim astrDevices

aboolAllDevAreKnown	= True
astrDevices 		= hs.GetINISetting("COMMON","DEVICES","",astrFile)
astrConfig  		= hs.GetINISetting("COMMON","CONFIG","..\scripts\config\",astrFile)
atabDv	 			= Split(astrDevices, G_SEP)
astrNbDv 			= UBound(atabDv) 
i=1
While (i <= Cint(astrNbDv))
	astrBuffer = hs.GetINISetting("DEVICE", "HC", "", astrConfig & atabDv(i)) & _ 
					hs.GetINISetting("DEVICE", "DC", "", astrConfig & atabDv(i))	
					
	If astrStatus = G_STATUS_EXIST then
		If hs.DeviceExists(astrBuffer) = -1 Then
			aboolAllDevAreKnown=False
			i=Cint(astrNbDv)
		End if
		
	Else
	
		If hs.DeviceStatus(astrBuffer) = astrStatus Then
			aboolAllDevAreKnown=False
			i=Cint(astrNbDv)
		End if
	End if
	
	i=i+1
Wend
CheckDevices=aboolAllDevAreKnown
End Function

'--------------------------------------------------------------------
'-- OBJECTIVE   : PROCEDURE >> Launch a common procedure on event changes
'-- PREREQUISITE: N/A
'-- PARAMS IN   : Homeseer device object 
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 11/04/2003
'--------------------------------------------------------------------
Sub traceDeviceChanges(aparm)
Dim astrHouseCode		
Dim astrDeviceCode
Dim astrStatus
Dim astrDevice
Dim aobjDevice

astrHouseCode  = aparm(0)
astrDeviceCode = aparm(1)
astrStatus     = aparm(2)
astrDevice     = astrHouseCode & astrDeviceCode
Set aobjDevice = hs.GetDeviceByRef(hs.GetDeviceRef(astrDevice))

If UCase(aobjDevice.dev_type_string) = UCase("Virtual") Then
	SaveDeviceChangeWithAuthor astrDevice, "hs.RegisterStatusChangeCB"
	
ElseIf UCase(aobjDevice.dev_type_string) = UCase("MS13") Then
	SaveDeviceChangeWithAuthor astrDevice, "hs.RegisterStatusChangeCB"
End If

Set aobjDevice = Nothing
End sub

'--------------------------------------------------------------------
'-- OBJECTIVE   : FUNCTION >> Generate an event file
'-- PREREQUISITE: N/A
'-- PARAMS IN   : aparamTYPE 	: AT
'--				  aparamTIME 	: 02:30
'--				  aparamNAME	: NAME
'--				  aparamSCRIPT	: SCRIPT to be launched
'--				  aparamGROUP	: EVT GROUP
'-- PARAMS OUT  : N/A
'-- CREATED BY DOMOTICS
'-- 11/04/2006
'--------------------------------------------------------------------

Function createEventFile(aparamTYPE, aparamTIME, aparamNAME, aparamSCRIPT, aparamGROUP, aparamFile)
Dim astrBuffer

If aparamTYPE="AT" Then
	astrBuffer = LoadFile(hs.GetAppPath & "\scripts\templates\template_evt_at.ini", False) 
	astrBuffer = replace(astrBuffer,"##NAME##",aparamNAME)
	astrBuffer = replace(astrBuffer,"##EVT_TIME##",aparamTIME)
	astrBuffer = replace(astrBuffer,"##SCRIPTS##",aparamSCRIPT)
	astrBuffer = replace(astrBuffer,"##GROUP##",aparamGROUP)
	SaveFilebyType aparamFile, astrBuffer, G_FILETYPE_SYSTEM
	'SaveFile aparamFile, astrBuffer
	createEventFile = True
Else
	createEventFile = False
End if

End Function

'--------------------------------------------------------------------
'-- OBJECTIVE   : PROCEDURE >> SetDevice Depending the related Policy
'-- PREREQUISITE: N/A
'-- PARAMS IN   : aparamDevice	: A1, B1, etc
'--				        aparamPolicy 	: [BETWEEN;07:15;08:15;ON] ...
'--               aparamInput   : Source like a webpage in some cases
'-- PARAMS OUT  : N/A (the related device is updated)
'-- CREATED BY DOMOTICS
'-- 20/06/2006
'------------------------------------------------------------------
Sub SetDeviceWithPolicy(byval aparamDevice, byval aparamPolicy, byval aparamInput)
Dim astrLog
Dim adevTmp
Dim aG_DEFAULT_SCRIPT
Dim astrReturn
Dim astrValue
Dim astrTypeValue

aG_DEFAULT_SCRIPT = G_DEFAULT_SCRIPT & ".SetDeviceWithPolicy"
astrValue = aparamInput
astrTypeValue = G_TYPE_STRING

If (aparamPolicy <> "") and (hs.DeviceExists(aparamDevice) > -1) then   	
	Set adevTmp = hs.GetDeviceByRef(hs.GetDeviceRef(aparamDevice))
	astrLog = adevTmp.dev_type_string & "." &  aparamDevice & " " 
	Set adevTmp = Nothing

	doExpression aparamPolicy, astrReturn, astrTypeValue, astrValue 
	WriteLog G_FOLDER_NAME, aG_DEFAULT_SCRIPT, G_TIV_INF, astrLog & "has a Policy which returns " & astrReturn & "/" & astrTypeValue & "/" & astrValue, G_LOG_FILE
  
  If astrReturn Then
      If (astrTypeValue = G_TYPE_STRING) and (astrValue = G_DEFAULT_VALUE) Then
          astrReturn = False
          WriteLog G_FOLDER_NAME, aG_DEFAULT_SCRIPT, G_TIV_INF, G_DEFAULT_VALUE & " cannot be assigned to " & aparamDevice, G_LOG_FILE
      End if
  End if        
	If astrReturn Then
      If astrTypeValue = G_TYPE_STRING Then 
          If isNumeric(replace(astrValue,G_NUMERIC_FROM_CHAR,G_NUMERIC_TO_CHAR)) Then
      			SetDevice aparamDevice, astrValue, "", CDbl(replace(astrValue,G_NUMERIC_FROM_CHAR,G_NUMERIC_TO_CHAR))
      		Else
      	 		SetDevice aparamDevice, astrValue, "", ""
      		End if
          
      Elseif (astrTypeValue = G_STATUS_ON) Then 
          SetDevice aparamDevice, "", G_STATUS_ON, ""
        
      Elseif (astrTypeValue = G_STATUS_OFF) Then
          SetDevice aparamDevice, "", G_STATUS_OFF, ""

      Elseif (astrTypeValue = G_STATUS_DIM) Then
          SetDevice aparamDevice, "", G_STATUS_DIM, astrValue

      Elseif (astrTypeValue = G_STATUS_BRIGHT) Then
          SetDevice aparamDevice, "", G_STATUS_BRIGHT, astrValue    

      Elseif (astrTypeValue = G_STATUS_DIM_FROM_BOTTOM) Then
          SetDevice aparamDevice, "", G_STATUS_DIM_FROM_BOTTOM, astrValue

      Elseif (astrTypeValue = G_STATUS_BRIGHT_FROM_BOTTOM) Then
          SetDevice aparamDevice, "", G_STATUS_BRIGHT_FROM_BOTTOM, astrValue
          
      Elseif (astrTypeValue = G_STATUS_DIM_FROM_TOP) Then
          SetDevice aparamDevice, "", G_STATUS_DIM_FROM_TOP, astrValue

      Elseif (astrTypeValue = G_STATUS_BRIGHT_FROM_TOP) Then
          SetDevice aparamDevice, "", G_STATUS_BRIGHT_FROM_TOP, astrValue   

      Elseif (astrTypeValue = G_STATUS_EXTENDED) Then
          SetDevice aparamDevice, "", G_STATUS_EXTENDED, astrValue                 
          
    	Else 
    		If isNumeric(replace(astrValue,G_NUMERIC_FROM_CHAR,G_NUMERIC_TO_CHAR)) Then
    			SetDevice aparamDevice, astrValue, "", CDbl(replace(astrValue,G_NUMERIC_FROM_CHAR,G_NUMERIC_TO_CHAR))
    		Else
    			SetDevice aparamDevice, astrValue, "", ""
    		End if      
      End if							
  End if
Else
  WriteLog G_FOLDER_NAME, aG_DEFAULT_SCRIPT, G_TIV_SEV, aparamDevice & " does not exist !!! (or policy is empty !!!)", G_LOG_FILE
End if	
End sub
